=================
Test presentation
=================

Sample
======

Head
----

.. revealjs-code-block:: python

   def hello():
       print("world")

.. revealjs-code-block:: php
   :data-line-numbers: 3,5

   <?php

   function hello() {
       print("world");
   }

.. revealjs-code-block:: toml
   :data-ln-start-from: 5

   [project]
   name = "sphinx-revealjs"
